<?php

namespace Drupal\entity_share_server\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Channel entity.
 *
 * @ConfigEntityType(
 *   id = "channel",
 *   label = @Translation("Channel"),
 *   handlers = {
 *     "list_builder" = "Drupal\entity_share_server\ChannelListBuilder",
 *     "form" = {
 *       "add" = "Drupal\entity_share_server\Form\ChannelForm",
 *       "edit" = "Drupal\entity_share_server\Form\ChannelForm",
 *       "delete" = "Drupal\entity_share_server\Form\ChannelDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\entity_share_server\ChannelHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "channel",
 *   admin_permission = "administer_channel_entity",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/services/entity_share/channel/{channel}",
 *     "add-form" = "/admin/config/services/entity_share/channel/add",
 *     "edit-form" = "/admin/config/services/entity_share/channel/{channel}/edit",
 *     "delete-form" = "/admin/config/services/entity_share/channel/{channel}/delete",
 *     "collection" = "/admin/config/services/entity_share/channel"
 *   }
 * )
 */
class Channel extends ConfigEntityBase implements ChannelInterface {

  /**
   * The channel ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The channel label.
   *
   * @var string
   */
  protected $label;

  /**
   * The channel entity type.
   *
   * @var string
   */
  protected $channel_entity_type;

  /**
   * The channel bundle.
   *
   * @var string
   */
  protected $channel_bundle;

  /**
   * The channel langcode.
   *
   * @var string
   */
  protected $channel_langcode;

  /**
   * The UUIDs of the users authorized to see this channel.
   *
   * @var string[]
   */
  protected $authorized_users;

  /**
   * {@inheritdoc}
   */
  public function removeAuthorizedUser($uuid) {
    $authorized_users = $this->authorized_users;
    if (($key = array_search($uuid, $authorized_users)) !== FALSE) {
      unset($authorized_users[$key]);
      $this->set('authorized_users', $authorized_users);
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function generateUri() {
    $uri_parts = [];
    if ($this->channel_langcode != 'und') {
      $uri_parts[] = $this->channel_langcode;
    }
    $uri_parts[] = 'jsonapi';
    $uri_parts[] = $this->channel_entity_type;
    $uri_parts[] = $this->channel_bundle;

    return implode('/', $uri_parts);
  }

}
